const LIMIT = 30
const app = Vue.createApp({
  setup() {
    document.body.removeAttribute('hidden')
  },
  data () {
    return {
      comments: []
    }
  },
  methods: {
    getClassName(comment) {
      if (comment.commentIndex % 2 === 0) {
        return 'comment even'
      }
      return 'comment odd'
    },
    getStyle(comment) {
      if (comment.data.colors) {
        const textColor = comment.data.colors.bodyTextColor
        const bgColor = comment.data.colors.bodyBackgroundColor
        const style = {
          '--lcv-background-color': bgColor,
          '--lcv-text-color': textColor,
          '--lcv-comment-shadow': 'none',
          '--lcv-neon-shadow': 'none',
          '--lcv-neon-box-shadow': 'none',
          '--lcv-box-shadow': `0 0 4px #fff,
          0 0 8px ${bgColor},
          0 0 12px ${bgColor},
          0 0 16px #f00,
          0 0 20px #f00,
          0 0 24px #f00,
          0 0 28px #f00,
          0 0 32px #f00`
        }
        return style
      }
    }
  },
  mounted () {
    let cache = new Map()
    commentIndex = 0
    OneSDK.setup({
      commentLimit: LIMIT
    })
    OneSDK.subscribe({
      action: 'comments',
      callback: (comments) => {
        const newCache = new Map()
        comments.forEach(comment => {
          const index = cache.get(comment.data.id)
          if (isNaN(index)) {
            comment.commentIndex = commentIndex
            newCache.set(comment.data.id, commentIndex)
            ++commentIndex
          } else {
            comment.commentIndex = index
            newCache.set(comment.data.id, index)
          }
        })
        cache = newCache
        this.comments = comments
      }
    })
    OneSDK.connect()
  },
})
app.component('one-marquee', window.OneMarquee())
OneSDK.ready().then(() => {
  app.mount("#container");
})
